16.136. cdist-type__rvm_ruby(7) — cdist 6.5.4 documentation

# 16.136. cdist-type__rvm_ruby(7)

## 16.136.1. NAME

cdist-type__rvm_ruby - Manage ruby installations through rvm

## 16.136.2. DESCRIPTION

RVM is the Ruby enVironment Manager for the Ruby programming language.

## 16.136.3. REQUIRED PARAMETERS

user
  The remote user account to use
state
  Either "present" or "absent", defaults to "present".

## 16.136.4. BOOLEAN PARAMETERS

default
  Set the given version as default

## 16.136.5. EXAMPLES

    # Install ruby 1.9.3 through rvm for user thelonious
    __rvm_ruby ruby-1.9.3-p0 --user thelonious --state present

    # Install ruby 1.9.3 through rvm for user ornette and make it the default
    __rvm_ruby ruby-1.9.3-p0 --user ornette --state present --default

    # Remove ruby 1.9.3 for user john
    __rvm_ruby ruby-1.9.3-p0 --user john --state absent

## 16.136.6. SEE ALSO

cdist-type__rvm(7), cdist-type__rvm_gem(7), cdist-type__rvm_gemset(7)

## 16.136.7. AUTHORS

Evax Software <contact@evax.fr>

## 16.136.8. COPYING

Copyright (C) 2012 Evax Software. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).